@@ -63,7 +63,7 @@ BEGIN {
 }
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '2.003_000';
+our $VERSION   = '2.005_001';
 our @EXPORT    = qw( eval_closure );
 our @EXPORT_OK = qw(
 	HAS_LEXICAL_SUBS HAS_LEXICAL_VARS ALIAS_IMPLEMENTATION
@@ -492,7 +492,7 @@ Boolean indicating whether Eval::TypeTiny has support for lexical subs.
 
 Returns a string indicating what implementation of C<< alias => 1 >> is
 being used. Eval::TypeTiny will automatically choose the best implementation.
-This constant can be matched against the C<< IMPLEMENTAION_* >> constants.
+This constant can be matched against the C<< IMPLEMENTATION_* >> constants.
 
 =item C<< IMPLEMENTATION_NATIVE >>
 
