@@ -12,7 +12,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Params::Signature::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Params::Signature::VERSION    = '2.003_000';
+	$Type::Params::Signature::VERSION    = '2.005_001';
 }
 
 $Type::Params::Signature::VERSION =~ tr/_//d;
@@ -160,6 +160,13 @@ sub _rationalize_slurpies {
 		Carp::carp( "Warning: the default for the slurpy parameter will be ignored, continuing anyway" );
 		delete $self->{slurpy}{default};
 	}
+	
+	if ( $self->{slurpy} and $self->{slurpy}->optional ) {
+		require Carp;
+		our @CARP_NOT = ( __PACKAGE__, 'Type::Params' );
+		Carp::carp( "Warning: the optional for the slurpy parameter will be ignored, continuing anyway" );
+		delete $self->{slurpy}{optional};
+	}
 }
 
 sub _parameters_from_list {
