@@ -10,7 +10,7 @@ BEGIN {
 
 BEGIN {
 	$Type::Tiny::AUTHORITY  = 'cpan:TOBYINK';
-	$Type::Tiny::VERSION    = '2.003_000';
+	$Type::Tiny::VERSION    = '2.005_001';
 	$Type::Tiny::XS_VERSION = '0.016';
 }
 
@@ -86,7 +86,7 @@ sub _croak ($;@) { require Error::TypeTiny; goto \&Error::TypeTiny::croak }
 sub _swap { $_[2] ? @_[ 1, 0 ] : @_[ 0, 1 ] }
 
 BEGIN {
-	my $support_smartmatch = 0+ !!( $] >= 5.010001 );
+	my $support_smartmatch = 0+ !!( $] >= 5.010001 && $] <= 5.041002 );
 	eval qq{ sub SUPPORT_SMARTMATCH () { !! $support_smartmatch } };
 	
 	my $fixed_precedence = 0+ !!( $] >= 5.014 );
@@ -1936,6 +1936,12 @@ You may pass C<< coercion => 1 >> to the constructor to inherit coercions
 from the constraint's parent. (This requires the parent constraint to have
 a coercion.)
 
+If an arrayref is passed to the constructor (C<< coercion => [ ... ] >>),
+then the coercion object will be lazily built and this array will be fed to
+its C<add_type_coercions> method. If a coderef is passed to the constructor
+(C<< coercion => sub { ... } >>), then the coercion object will be lazily built
+and this code will be used as a coercion from B<Any>.
+
 =item C<< sorter >>
 
 A coderef which can be passed two values conforming to this type constraint
