@@ -11,7 +11,7 @@ BEGIN {
 
 BEGIN {
 	$Types::Standard::AUTHORITY = 'cpan:TOBYINK';
-	$Types::Standard::VERSION   = '2.003_000';
+	$Types::Standard::VERSION   = '2.005_001';
 }
 
 $Types::Standard::VERSION =~ tr/_//d;
@@ -1097,7 +1097,7 @@ $meta->add_coercion(
 			my ( $self, $target, $re ) = @_;
 			ref( $re ) eq q(Regexp)
 				or _croak(
-				"Parameter to Split[`a] expected to be a regular expresssion; got $re" );
+				"Parameter to Split[`a] expected to be a regular expression; got $re" );
 			my $regexp_string = "$re";
 			$regexp_string =~ s/\\\//\\\\\//g;    # toothpicks
 			return ( Str(), qq{ [split /$regexp_string/, \$_] } );
@@ -1229,6 +1229,8 @@ B<< Bool >>
 Values that are reasonable booleans. Accepts 1, 0, the empty string and
 undef.
 
+Other customers also bought: B<< BoolLike >> from L<Types::TypeTiny>.
+
 =item *
 
 B<< Maybe[`a] >>
@@ -1710,7 +1712,7 @@ strings, the 1st, 4th, 7th, etc values are integers, and the 2nd,
 
 =head2 Coercions
 
-Most of the types in this type library have no coercions by default.
+Most of the types in this type library have no coercions.
 The exception is B<Bool> as of Types::Standard 1.003_003, which coerces
 from B<Any> via C<< !!$_ >>.
 
@@ -1788,7 +1790,7 @@ C<looks_like_number>.
 
 =item C<PERL_TYPE_TINY_XS>
 
-If set to false, can be used to suppress the loading of XS implementions of
+If set to false, can be used to suppress the loading of XS implementations of
 some type constraints.
 
 =item C<PERL_ONLY>
